@@ -1,6 +1,7 @@
 import datetime
 import logging
 import os
+import shutil
 import signal
 import subprocess
 import textwrap
@@ -106,6 +107,9 @@ def hwclock_has_compare(cmdmod):
     systems where it's not present so that we can skip the
     comparison portion of the test.
     """
+    hwclock = shutil.which("hwclock")
+    if hwclock is None:
+        pytest.skip("The 'hwclock' binary could not be found")
     res = cmdmod.run_all(cmd="hwclock -h")
     _hwclock_has_compare_ = res["retcode"] == 0 and res["stdout"].find("--compare") > 0
     return _hwclock_has_compare_
