@@ -1,6 +1,7 @@
 """
 :codeauthor: Gareth J. Greenaway (ggreenaway@vmware.com)
 """
+
 import logging
 import random
 
@@ -9,6 +10,7 @@ from pytestshellutils.exceptions import FactoryNotStarted
 from saltfactories.utils import random_string
 
 import salt.defaults.exitcodes
+from tests.conftest import FIPS_TESTRUN
 from tests.support.helpers import PRE_PYTEST_SKIP_REASON
 
 log = logging.getLogger(__name__)
@@ -128,6 +130,11 @@ def test_exit_status_correct_usage(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     proxy_two = "dummy_proxy_two"
 
@@ -170,17 +177,20 @@ def test_exit_status_correct_usage(
         "controlproxy.sls", controlproxy_pillar_file
     )
     dummy_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_one),
+        f"{proxy_one}.sls",
         dummy_proxy_one_pillar_file,
     )
     dummy_proxy_two_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_two),
+        f"{proxy_two}.sls",
         dummy_proxy_two_pillar_file,
     )
-    with top_tempfile, controlproxy_tempfile, dummy_proxy_one_tempfile, dummy_proxy_two_tempfile:
+    with (
+        top_tempfile
+    ), controlproxy_tempfile, dummy_proxy_one_tempfile, dummy_proxy_two_tempfile:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -243,6 +253,11 @@ def test_missing_pillar_file(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     proxy_two = "dummy_proxy_two"
 
@@ -277,13 +292,14 @@ def test_missing_pillar_file(
         "controlproxy.sls", controlproxy_pillar_file
     )
     dummy_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_one),
+        f"{proxy_one}.sls",
         dummy_proxy_one_pillar_file,
     )
     with top_tempfile, controlproxy_tempfile, dummy_proxy_one_tempfile:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -341,6 +357,11 @@ def test_invalid_connection(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "dummy_proxy_one"
     broken_proxy_one = "broken_proxy_one"
     broken_proxy_two = "broken_proxy_two"
@@ -395,19 +416,24 @@ def test_invalid_connection(
         "controlproxy.sls", controlproxy_pillar_file
     )
     dummy_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_one),
+        f"{proxy_one}.sls",
         dummy_proxy_one_pillar_file,
     )
     broken_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(broken_proxy_one), broken_proxy_one_pillar_file
+        f"{broken_proxy_one}.sls", broken_proxy_one_pillar_file
     )
     broken_proxy_two_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(broken_proxy_two), broken_proxy_two_pillar_file
+        f"{broken_proxy_two}.sls", broken_proxy_two_pillar_file
     )
-    with top_tempfile, controlproxy_tempfile, dummy_proxy_one_tempfile, broken_proxy_one_tempfile, broken_proxy_two_tempfile:
+    with (
+        top_tempfile
+    ), (
+        controlproxy_tempfile
+    ), dummy_proxy_one_tempfile, broken_proxy_one_tempfile, broken_proxy_two_tempfile:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -467,6 +493,11 @@ def test_custom_proxy_module(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "custom_dummy_proxy_one"
     proxy_two = "custom_dummy_proxy_two"
 
@@ -522,21 +553,26 @@ def ping():
         "controlproxy.sls", controlproxy_pillar_file
     )
     dummy_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_one),
+        f"{proxy_one}.sls",
         dummy_proxy_one_pillar_file,
     )
     dummy_proxy_two_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_two),
+        f"{proxy_two}.sls",
         dummy_proxy_two_pillar_file,
     )
 
     custom_proxy_module = salt_master.state_tree.base.temp_file(
         "_proxy/custom_dummy.py", module_contents
     )
-    with top_tempfile, controlproxy_tempfile, dummy_proxy_one_tempfile, dummy_proxy_two_tempfile, custom_proxy_module:
+    with (
+        top_tempfile
+    ), (
+        controlproxy_tempfile
+    ), dummy_proxy_one_tempfile, dummy_proxy_two_tempfile, custom_proxy_module:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -600,6 +636,11 @@ def test_custom_proxy_module_raise_exception(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     proxy_one = "custom_dummy_proxy_one"
     proxy_two = "custom_dummy_proxy_two"
 
@@ -655,21 +696,26 @@ def ping():
         "controlproxy.sls", controlproxy_pillar_file
     )
     dummy_proxy_one_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_one),
+        f"{proxy_one}.sls",
         dummy_proxy_one_pillar_file,
     )
     dummy_proxy_two_tempfile = salt_master.pillar_tree.base.temp_file(
-        "{}.sls".format(proxy_two),
+        f"{proxy_two}.sls",
         dummy_proxy_two_pillar_file,
     )
 
     custom_proxy_module = salt_master.state_tree.base.temp_file(
         "_proxy/custom_dummy.py", module_contents
     )
-    with top_tempfile, controlproxy_tempfile, dummy_proxy_one_tempfile, dummy_proxy_two_tempfile, custom_proxy_module:
+    with (
+        top_tempfile
+    ), (
+        controlproxy_tempfile
+    ), dummy_proxy_one_tempfile, dummy_proxy_two_tempfile, custom_proxy_module:
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
@@ -735,6 +781,11 @@ def test_exit_status_correct_usage_large_number_of_minions(
     config_defaults = {
         "metaproxy": "deltaproxy",
     }
+    config_overrides = {
+        "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+    }
     sub_proxies = [
         "proxy_one",
         "proxy_two",
@@ -811,6 +862,7 @@ def test_exit_status_correct_usage_large_number_of_minions(
         factory = salt_master.salt_proxy_minion_daemon(
             proxy_minion_id,
             defaults=config_defaults,
+            overrides=config_overrides,
             extra_cli_arguments_after_first_start_failure=["--log-level=info"],
             start_timeout=320,
         )
