@@ -11,8 +11,8 @@ pytestmark = [
     pytest.mark.slow_test,
     pytest.mark.requires_sshd_server,
     pytest.mark.skipif(
-        "grains['osfinger'] == 'Fedora Linux-39'",
-        reason="Fedora 39 ships with Python 3.12. Test can't run with system Python on 3.12",
+        'grains["osfinger"].startswith(("Fedora Linux-40", "Ubuntu-24.04", "Arch Linux"))',
+        reason="System ships with a version of python that is too recent for salt-ssh tests",
         # Actually, the problem is that the tornado we ship is not prepared for Python 3.12,
         # and it imports `ssl` and checks if the `match_hostname` function is defined, which
         # has been deprecated since Python 3.7, so, the logic goes into trying to import
