@@ -11,7 +11,8 @@ from pytestskipmarkers.utils import platform
 from saltfactories.utils import random_string
 
 import salt.config
-from tests.conftest import CODE_DIR
+import salt.utils.files
+from tests.conftest import CODE_DIR, FIPS_TESTRUN
 from tests.support.pkg import ApiRequest, SaltMaster, SaltMasterWindows, SaltPkgInstall
 
 log = logging.getLogger(__name__)
@@ -89,12 +90,6 @@ def pytest_addoption(parser):
         action="store_true",
         help="Do not uninstall salt packages after test run is complete",
     )
-    test_selection_group.addoption(
-        "--classic",
-        default=False,
-        action="store_true",
-        help="Test an upgrade from the classic packages.",
-    )
     test_selection_group.addoption(
         "--prev-version",
         action="store",
@@ -113,13 +108,66 @@ def pytest_addoption(parser):
     )
 
 
+@pytest.hookimpl(hookwrapper=True, trylast=True)
+def pytest_collection_modifyitems(config, items):
+    """
+    called after collection has been performed, may filter or re-order
+    the items in-place.
+
+    :param _pytest.main.Session session: the pytest session object
+    :param _pytest.config.Config config: pytest config object
+    :param List[_pytest.nodes.Item] items: list of item objects
+    """
+    # Let PyTest or other plugins handle the initial collection
+    yield
+    selected = []
+    deselected = []
+    pkg_tests_path = pathlib.Path(__file__).parent
+
+    if config.getoption("--upgrade"):
+        for item in items:
+            if str(item.fspath).startswith(str(pkg_tests_path / "upgrade")):
+                selected.append(item)
+            else:
+                deselected.append(item)
+    elif config.getoption("--downgrade"):
+        for item in items:
+            if str(item.fspath).startswith(str(pkg_tests_path / "downgrade")):
+                selected.append(item)
+            else:
+                deselected.append(item)
+    elif config.getoption("--download-pkgs"):
+        for item in items:
+            if str(item.fspath).startswith(str(pkg_tests_path / "download")):
+                selected.append(item)
+            else:
+                deselected.append(item)
+    else:
+        exclude_paths = (
+            str(pkg_tests_path / "upgrade"),
+            str(pkg_tests_path / "downgrade"),
+            str(pkg_tests_path / "download"),
+        )
+        for item in items:
+            if str(item.fspath).startswith(exclude_paths):
+                deselected.append(item)
+            else:
+                selected.append(item)
+
+    if deselected:
+        # Selection changed
+        items[:] = selected
+        config.hook.pytest_deselected(items=deselected)
+
+
 @pytest.hookimpl(tryfirst=True)
 def pytest_runtest_setup(item):
     """
     Fixtures injection based on markers or test skips based on CLI arguments
     """
+    pkg_tests_path = pathlib.Path(__file__).parent
     if (
-        str(item.fspath).startswith(str(pathlib.Path(__file__).parent / "download"))
+        str(item.fspath).startswith(str(pkg_tests_path / "download"))
         and item.config.getoption("--download-pkgs") is False
     ):
         raise pytest.skip.Exception(
@@ -128,6 +176,17 @@ def pytest_runtest_setup(item):
             _use_item_location=True,
         )
 
+    for key in ("upgrade", "downgrade"):
+        if (
+            str(item.fspath).startswith(str(pkg_tests_path / key))
+            and item.config.getoption(f"--{key}") is False
+        ):
+            raise pytest.skip.Exception(
+                f"The package {key} tests are disabled. Pass '--{key}' to pytest "
+                "to enable them.",
+                _use_item_location=True,
+            )
+
 
 @pytest.fixture(scope="session")
 def salt_factories_root_dir(request, tmp_path_factory):
@@ -166,7 +225,6 @@ def install_salt(request, salt_factories_root_dir):
         downgrade=request.config.getoption("--downgrade"),
         no_uninstall=request.config.getoption("--no-uninstall"),
         no_install=request.config.getoption("--no-install"),
-        classic=request.config.getoption("--classic"),
         prev_version=request.config.getoption("--prev-version"),
         use_prev_version=request.config.getoption("--use-prev-version"),
     ) as fixture:
@@ -233,18 +291,25 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
             },
         },
         "fips_mode": FIPS_TESTRUN,
+        "publish_signing_algorithm": (
+            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
+        ),
         "open_mode": True,
     }
-    test_user = False
+    salt_user_in_config_file = False
     master_config = install_salt.config_path / "master"
-    if master_config.exists():
+    if master_config.exists() and master_config.stat().st_size:
         with salt.utils.files.fopen(master_config) as fp:
             data = yaml.safe_load(fp)
-            if data and "user" in data:
-                test_user = True
+            if data is None:
+                # File exists but is mostly commented out
+                data = {}
+            user_in_config_file = data.get("user")
+            if user_in_config_file and user_in_config_file == "salt":
+                salt_user_in_config_file = True
                 # We are testing a different user, so we need to test the system
                 # configs, or else permissions will not be correct.
-                config_overrides["user"] = data["user"]
+                config_overrides["user"] = user_in_config_file
                 config_overrides["log_file"] = salt.config.DEFAULT_MASTER_OPTS.get(
                     "log_file"
                 )
@@ -270,8 +335,18 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
                     pathlib.Path("/var", "cache", "salt", "master"),
                 ]
                 for _file in verify_files:
-                    assert _file.owner() == "salt"
-                    assert _file.group() == "salt"
+                    if _file.owner() != "salt":
+                        log.warning(
+                            "The owner of '%s' is '%s' when it should be 'salt'",
+                            _file,
+                            _file.owner(),
+                        )
+                    if _file.group() != "salt":
+                        log.warning(
+                            "The group of '%s' is '%s' when it should be 'salt'",
+                            _file,
+                            _file.group(),
+                        )
 
     master_script = False
     if platform.is_windows():
@@ -321,7 +396,7 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
             salt_pkg_install=install_salt,
         )
     factory.after_terminate(pytest.helpers.remove_stale_master_key, factory)
-    if test_user:
+    if salt_user_in_config_file:
         # Salt factories calls salt.utils.verify.verify_env
         # which sets root perms on /etc/salt/pki/master since we are running
         # the test suite as root, but we want to run Salt master as salt
@@ -370,6 +445,8 @@ def salt_minion(salt_factories, salt_master, install_salt):
         "file_roots": salt_master.config["file_roots"].copy(),
         "pillar_roots": salt_master.config["pillar_roots"].copy(),
         "fips_mode": FIPS_TESTRUN,
+        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
+        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
         "open_mode": True,
     }
     if platform.is_windows():
@@ -397,13 +474,21 @@ def salt_minion(salt_factories, salt_master, install_salt):
     # which sets root perms on /srv/salt and /srv/pillar since we are running
     # the test suite as root, but we want to run Salt master as salt
     if not platform.is_windows() and not platform.is_darwin():
-        state_tree = "/srv/salt"
-        pillar_tree = "/srv/pillar"
-        check_paths = [state_tree, pillar_tree, CODE_DIR / ".nox"]
-        for path in check_paths:
-            if os.path.exists(path) is False:
-                continue
-            subprocess.run(["chown", "-R", "salt:salt", str(path)], check=False)
+        import pwd
+
+        try:
+            pwd.getpwnam("salt")
+        except KeyError:
+            # The salt user does not exist
+            pass
+        else:
+            state_tree = "/srv/salt"
+            pillar_tree = "/srv/pillar"
+            check_paths = [state_tree, pillar_tree, CODE_DIR / ".nox"]
+            for path in check_paths:
+                if os.path.exists(path) is False:
+                    continue
+                subprocess.run(["chown", "-R", "salt:salt", str(path)], check=False)
 
     factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master, factory.id
