@@ -52,7 +52,11 @@ def test_purge(job1):
         schedule, "list_", MagicMock(return_value=_schedule_data)
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_list:
+    with (
+        patch_makedirs
+    ), (
+        patch_schedule_opts
+    ), patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_list:
         assert schedule.purge() == {
             "comment": ["Deleted job: job1 from schedule."],
             "changes": {"job1": "removed"},
@@ -103,7 +107,9 @@ def test_delete(job1):
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         assert schedule.delete("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -339,7 +345,9 @@ def test_run_job(job1):
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         assert schedule.run_job("job1") == {
             "comment": "Scheduling Job job1 on minion.",
             "result": True,
@@ -365,7 +373,9 @@ def test_enable_job():
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         assert schedule.enable_job("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -392,7 +402,9 @@ def test_disable_job():
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         assert schedule.disable_job("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -474,7 +486,9 @@ def test_move(job1):
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -516,7 +530,9 @@ def test_move(job1):
 
         mock = MagicMock(side_effect=[{}, {"job1": {}}])
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         with patch.dict(schedule.__pillar__, {"schedule": {"job1": job1}}):
             mock = MagicMock(return_value={})
             patch_schedule_publish = patch.dict(
@@ -576,7 +592,9 @@ def test_copy(job1):
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -616,7 +634,9 @@ def test_copy(job1):
             "result": False,
         }
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -887,7 +907,9 @@ def test_is_enabled():
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
         ret = schedule.is_enabled("job1")
         assert ret == job1
 
@@ -925,7 +947,9 @@ def test_job_status():
         SaltEvent, "get_event", return_value={"complete": True, "data": job1}
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
+    with (
+        patch_makedirs
+    ), patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
         ret = schedule.job_status("job1")
         assert ret == {
             "_last_run": "2021-11-01T12:36:57",
@@ -978,7 +1002,11 @@ def test_list(job1):
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with (
+        patch_schedule_opts
+    ), (
+        patch_schedule_event_fire
+    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1006,7 +1034,13 @@ def test_list(job1):
     seconds: 10
 """
 
-    with patch_schedule_opts, patch_makedirs, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_os_path_exists:
+    with (
+        patch_schedule_opts
+    ), (
+        patch_makedirs
+    ), (
+        patch_schedule_event_fire
+    ), patch_schedule_get_event, patch_schedule_os_path_exists:
         with patch("salt.utils.files.fopen", mock_open(read_data="")) as fopen_mock:
             ret = schedule.list_()
             assert ret == expected
@@ -1038,7 +1072,11 @@ def test_list(job1):
     seconds: 10
 """
 
-    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with (
+        patch_schedule_opts
+    ), (
+        patch_schedule_event_fire
+    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1094,7 +1132,11 @@ def test_list_global_enabled(job1):
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with (
+        patch_schedule_opts
+    ), (
+        patch_schedule_event_fire
+    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1151,7 +1193,11 @@ def test_list_global_disabled(job1):
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with (
+        patch_schedule_opts
+    ), (
+        patch_schedule_event_fire
+    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
