@@ -619,7 +619,7 @@ def test_removed_purged_with_changes_test_true(list_pkgs, action):
             "pkg_resource.version_clean": MagicMock(return_value=None),
         },
     ):
-        expected = {"pkga": {"new": "{}".format(action), "old": ""}}
+        expected = {"pkga": {"new": f"{action}", "old": ""}}
         pkg_actions = {"removed": pkg.removed, "purged": pkg.purged}
 
         # Run state with test=true
@@ -689,7 +689,7 @@ def test_held_unheld(package_manager):
                         "name": pkg,
                         "changes": {"new": "hold", "old": ""},
                         "result": True,
-                        "comment": "Package {} is now being held.".format(pkg),
+                        "comment": f"Package {pkg} is now being held.",
                     }
                 }
             )
@@ -706,7 +706,7 @@ def test_held_unheld(package_manager):
                         "name": pkg,
                         "changes": {"new": "", "old": "hold"},
                         "result": True,
-                        "comment": "Package {} is no longer held.".format(pkg),
+                        "comment": f"Package {pkg} is no longer held.",
                     }
                 }
             )
