@@ -329,6 +329,11 @@ class TestAccount:
             ret = self.sminion.functions.user.add(self.username)
             assert ret is True
             self._delete_account = True
+        if salt.utils.platform.is_windows():
+            log.debug("Configuring system account: %s", self)
+            ret = self.sminion.functions.user.update(
+                self.username, password_never_expires=True
+            )
         if salt.utils.platform.is_darwin() or salt.utils.platform.is_windows():
             password = self.password
         else:
