@@ -2,13 +2,13 @@
     :codeauthor: Mike Place <mp@saltstack.com>
 """
 
-
 import errno
 import logging
 import os
 import threading
 
 import pytest
+
 import salt.config
 import salt.exceptions
 import salt.ext.tornado.gen
@@ -18,7 +18,6 @@ import salt.transport.ipc
 import salt.utils.platform
 from salt.ext.tornado.iostream import StreamClosedError
 from tests.support.runtests import RUNTIME_VARS
-from tests.support.unit import skipIf
 
 pytestmark = [
     pytest.mark.skip_on_darwin,
@@ -29,7 +28,7 @@ pytestmark = [
 log = logging.getLogger(__name__)
 
 
-@skipIf(salt.utils.platform.is_windows(), "Windows does not support Posix IPC")
+@pytest.mark.skip_on_windows(reason="Windows does not support Posix IPC")
 class IPCMessagePubSubCase(salt.ext.tornado.testing.AsyncTestCase):
     """
     Test all of the clear msg stuff
@@ -126,7 +125,6 @@ class IPCMessagePubSubCase(salt.ext.tornado.testing.AsyncTestCase):
         self.assertEqual(ret1, "TEST")
         self.assertEqual(ret2, "TEST")
 
-    @pytest.mark.flaky(max_runs=10)
     @salt.ext.tornado.testing.gen_test
     def test_async_reading_streamclosederror(self):
         client1 = self.sub_channel
